Changelog for websauna.system
=============================

1.0a8 (2018-03-03)
------------------

* websauna.system split down as component from main Websauna (For previous changes, check the main websauna project.)
